@@ -108,7 +108,7 @@ static gboolean update_function (gpointer data){
        g_strlcat(tiptext,_(" (Paused)"),64);
 
      gtk_progress_bar_set_fraction  (GTK_PROGRESS_BAR(pd->pbar),
-                    ((gdouble)elapsed_sec)/pd->timeout_period_in_sec);
+                    1.0-((gdouble)elapsed_sec)/pd->timeout_period_in_sec);
 
      gtk_tooltips_set_tip(pd->tip,GTK_WIDGET(pd->base),tiptext,NULL);
 
@@ -897,6 +897,104 @@ static void remove_clicked(GtkButton *button, gpointer data){
 
 }
 
+/**
+ * Moves an alarm one row up in the list
+**/
+static void up_clicked(GtkButton *button, gpointer data){
+
+  plugin_data *pd = (plugin_data *)data;
+
+  GtkTreeIter iter,iter_prev;
+  GtkTreeSelection *select;
+  gboolean valid;
+  gint row_count;
+
+  /* Get the selected row */
+  select=gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->tree));
+
+  valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(pd->list), &iter_prev);
+  
+  /* First item can't be moved up */
+  if(!valid || gtk_tree_selection_iter_is_selected(select,&iter_prev))
+	return;
+
+  iter = iter_prev;
+  valid = gtk_tree_model_iter_next (GTK_TREE_MODEL(pd->list), &iter);
+ 
+  row_count=1;
+
+  while (valid){
+
+
+     /* The selected one is swapped with the previous one */
+     if(gtk_tree_selection_iter_is_selected(select,&iter)){
+
+	   gtk_list_store_swap(pd->list, &iter, &iter_prev);
+       if(pd->selected == row_count) /* Update the index of the selected item */
+          pd->selected = row_count-1;          
+       else if(pd->selected == row_count-1)
+          pd->selected = row_count;
+       break;
+     }
+
+	 iter_prev = iter;
+     valid = gtk_tree_model_iter_next (GTK_TREE_MODEL(pd->list), &iter);    
+     row_count++;   
+
+  }
+
+  make_menu(pd);
+
+}
+
+/**
+ * Moves an alarm one row down in the list
+**/
+static void down_clicked(GtkButton *button, gpointer data){
+
+  plugin_data *pd = (plugin_data *)data;
+
+  GtkTreeIter iter,iter_next;
+  GtkTreeSelection *select;
+  gboolean valid;
+  gint row_count;
+
+  /* Get the selected row */
+  select=gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->tree));
+
+  valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(pd->list), &iter);
+
+  if(!valid)
+	return;
+
+  iter_next = iter;
+  valid = gtk_tree_model_iter_next (GTK_TREE_MODEL(pd->list), &iter_next);
+ 
+  row_count=0;
+
+  while (valid){
+
+
+     /* The selected one is swapped with the next one */
+     if(gtk_tree_selection_iter_is_selected(select,&iter)){
+
+	   gtk_list_store_swap(pd->list, &iter, &iter_next);
+       if(pd->selected == row_count) /* Update the index of the selected item */
+          pd->selected = row_count+1;          
+       else if(pd->selected == row_count+1)
+          pd->selected = row_count - 1;
+       break;
+     }
+
+	 iter = iter_next;
+     valid = gtk_tree_model_iter_next (GTK_TREE_MODEL(pd->list), &iter_next);    
+     row_count++;   
+
+  }
+
+  make_menu(pd);
+
+}
 
 /**
  * Adds the progressbar, taking into account the orientation.
@@ -904,7 +1002,9 @@ static void remove_clicked(GtkButton *button, gpointer data){
 **/
 static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
 
-  gtk_widget_hide(pd->eventbox);
+  //g_signal_handler_disconnect (G_OBJECT(plugin), pd->handler);
+
+  gtk_widget_hide(GTK_WIDGET(plugin));
 
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
@@ -918,7 +1018,7 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
   /* vertical bar */
   if(xfce_panel_plugin_get_orientation(plugin)==GTK_ORIENTATION_HORIZONTAL){
     pd->box=gtk_hbox_new(TRUE,0);
-    gtk_container_add(GTK_CONTAINER(pd->eventbox),pd->box);
+    gtk_container_add(GTK_CONTAINER(plugin),pd->box);
     gtk_progress_bar_set_orientation    (GTK_PROGRESS_BAR(pd->
                     pbar),GTK_PROGRESS_BOTTOM_TO_TOP);
     gtk_widget_set_size_request(GTK_WIDGET(pd->pbar),PBAR_THICKNESS,0);
@@ -929,7 +1029,7 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
   }
   else{ /* horizontal bar */
     pd->box=gtk_vbox_new(TRUE,0);
-    gtk_container_add(GTK_CONTAINER(pd->eventbox),pd->box);
+    gtk_container_add(GTK_CONTAINER(plugin),pd->box);
     gtk_progress_bar_set_orientation    (GTK_PROGRESS_BAR(pd->
                     pbar),GTK_PROGRESS_LEFT_TO_RIGHT);
     gtk_widget_set_size_request(GTK_WIDGET(pd->pbar),0,PBAR_THICKNESS);
@@ -938,8 +1038,11 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
     gtk_box_pack_start(GTK_BOX(pd->box),gtk_hseparator_new(),FALSE,FALSE,0);
 
   }
+  
+  gtk_widget_show_all(GTK_WIDGET(plugin));
 
-  gtk_widget_show_all(pd->eventbox);
+  g_signal_connect  (G_OBJECT(plugin), "button_press_event",
+            G_CALLBACK(pbar_clicked), pd);       
 }
 
 /**
@@ -1150,6 +1253,8 @@ static void tree_selected (GtkTreeSelection *select, gpointer data){
 
   gtk_widget_set_sensitive(pd->buttonedit,TRUE);
   gtk_widget_set_sensitive(pd->buttonremove,TRUE);
+  gtk_widget_set_sensitive(pd->buttonup,TRUE);
+  gtk_widget_set_sensitive(pd->buttondown,TRUE);
 
 }
 
@@ -1189,7 +1294,6 @@ plugin_free (XfcePanelPlugin *plugin, plugin_data *pd)
     g_array_free(pd->menuarray,TRUE);
 
   /* destroy all widgets */
-  gtk_widget_destroy(GTK_WIDGET(pd->eventbox));
 
   /* destroy the tooltips */
   /*gtk_object_destroy(GTK_OBJECT(pd->tip));*/
@@ -1364,21 +1468,33 @@ static void plugin_create_options (XfcePanelPlugin *plugin,plugin_data *pd) {
   pd->buttonadd=button;
   gtk_box_pack_start(GTK_BOX (buttonbox), button, FALSE, FALSE,WIDGET_SPACING<<1);
   gtk_widget_set_sensitive(button,TRUE);
-  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(add_edit_clicked),                                     pd);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(add_edit_clicked), pd);
 
 
   button = gtk_button_new_from_stock (GTK_STOCK_EDIT);
   pd->buttonedit=button;
   gtk_box_pack_start(GTK_BOX (buttonbox), button, FALSE, FALSE,WIDGET_SPACING<<1);
   gtk_widget_set_sensitive(button,FALSE);
-  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(add_edit_clicked),                                     pd);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(add_edit_clicked), pd);
 
   button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   pd->buttonremove=button;
   gtk_box_pack_start(GTK_BOX (buttonbox), button, FALSE, FALSE,WIDGET_SPACING);
   gtk_widget_set_sensitive(button,FALSE);
-  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(remove_clicked),                                       pd);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(remove_clicked), pd);
 
+  button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
+  pd->buttonup=button;
+  gtk_box_pack_start(GTK_BOX (buttonbox), button, FALSE, FALSE,WIDGET_SPACING);
+  gtk_widget_set_sensitive(button,FALSE);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(up_clicked), pd);
+  
+  button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
+  pd->buttondown=button;
+  gtk_box_pack_start(GTK_BOX (buttonbox), button, FALSE, FALSE,WIDGET_SPACING);
+  gtk_widget_set_sensitive(button,FALSE);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK(down_clicked), pd);
+  
   gtk_box_pack_start(GTK_BOX(vbox),gtk_hseparator_new(),FALSE,FALSE,BORDER);
 
   button=gtk_check_button_new_with_label(_("Don't display a warning  if an alarm command is set"));
@@ -1453,8 +1569,6 @@ create_plugin_control (XfcePanelPlugin *plugin)
          G_TYPE_INT);    /* Timer period in seconds if countdown.
                     Alarm time in minutes if 24h format is used,
                     (i.e. 60 x Hr + Min) */
-
-  pd->eventbox=gtk_event_box_new();
   pd->box=NULL;
   pd->timer_on=FALSE;
   pd->timeout=0;
@@ -1493,10 +1607,7 @@ create_plugin_control (XfcePanelPlugin *plugin)
   load_settings(pd);
 
   make_menu(pd);
-
-  g_signal_connect  (G_OBJECT(pd->eventbox), "button_press_event",
-            G_CALLBACK(pbar_clicked), pd);
-
+                      
   gtk_progress_bar_set_bar_style    (GTK_PROGRESS_BAR(pd->pbar),
                     GTK_PROGRESS_CONTINUOUS);
   gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pd->pbar),0);
@@ -1504,12 +1615,9 @@ create_plugin_control (XfcePanelPlugin *plugin)
   add_pbar(pd->base,pd);
 
   /* Trying to get a thin box, but no way */
-  /*gtk_widget_set_size_request(pd->eventbox,0,0);*/
   gtk_widget_set_size_request(GTK_WIDGET(plugin),10,10);
   xfce_panel_plugin_set_expand(plugin,FALSE);
 
-  gtk_container_add(GTK_CONTAINER(plugin),pd->eventbox);
-
   gtk_widget_show_all(GTK_WIDGET(plugin));
 
   g_signal_connect (plugin, "free-data",
